/*
 * Definitions for SUNTAC U-Cable P (PHS/PDC adapter) driver
 *
 *   Copyright (C) 2002 Trap (CXL00145@nifty.ne.jp)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 * This driver is for the device Suntac U-Cable P (Japanese Personal
 * Handyphone System adapter).
 */

#ifndef __LINUX_USB_SERIAL_SUNTAC_UCABLEP_H
#define __LINUX_USB_SERIAL_SUNTAC_UCABLEP_H

#define SUNTAC_VID			0x05db	/* Vendor Id */
#define SUNTAC_UCP_P_PID		0x0005	/* Product Id for type P*/
#define SUNTAC_UCP_D_PID		0x0003	/* Product Id for type D */

/*
 * Vendor Request Interface
 */
#define REQTYPE_DEVICE			0xc0
#define	REQ_DEVRESET			0xd0

#define REQTYPE_SERIAL			0x40
#define REQ_SET_BAUDRATE		0x10 
#define	REQ_SET_LINESTATE		0x11
#define	REQ_SET_DATABITS		0x12
#define	REQ_DEVCLOSE			0xe0

/*
 * LineState
 */
#define	SUNTAC_UCP_BREAK_bit		0x40
#define	SUNTAC_UCP_DTR_bit		0x01	/* Activate DTR */
#define	SUNTAC_UCP_RTS_bit		0x02	/* Activate RTS */

/*
 * Databits
 */
#define SUNTAC_UCP_DATA_BITS_7		0x01
#define SUNTAC_UCP_DATA_BITS_8		0x03

#define SUNTAC_UCP_PARITY_USE		0x80
#define SUNTAC_UCP_PARITY_NOUSE		0x0

#define	SUNTAC_UCP_PARITY_EVEN		0x10
#define	SUNTAC_UCP_PARITY_ODD		0x0
#define	SUNTAC_UCP_STICKPARITY		0x20
#define	SUNTAC_UCP_STOPBIT		0x04

/*
 * Modem Status Register (MSR)
 */
#define SUNTAC_UCP_MSR_INDEX		0x1	/* data[index] */

#define SUNTAC_UCP_MSR_CD		0x08	/* Current CD    (1:On, 0:Off) */
#define SUNTAC_UCP_MSR_RI		0x04	/* Current RI    (1:On, 0:Off) */
#define SUNTAC_UCP_MSR_DSR		0x02	/* Current DSR   (1:On, 0:Off) */
#define SUNTAC_UCP_MSR_CTS		0x01	/* Current CTS   (1:On, 0:Off) */
#define	SUNTAC_UCP_BREAK		0x80	/* Current BREAK (1:Yes, 0:No) */

#endif /* __LINUX_USB_SERIAL_SUNTAC_UCABLEP_H */

